vii_sdk
=======

vii_sdk is a Python library for communicating with
a Vii Horizon server. It is used for building Vii apps on Python.

It provides:

- a networking layer API for Horizon endpoints.
- facilities for building and signing transactions, for communicating with a Vii Horizon instance, and for submitting transactions or querying network history.

Installing
----------

Install from pypi:

.. code-block:: text

    pip install -U vii-sdk
